package appmain;
import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;
/**
* This class implements a minimal J2ME MIDlet to show the various 
* life cycle methods and provide an example for working out
* the details of compiling, packaging, and running midlets.
* Besides, a Hello World program must exist in all environments
* in order for the universe to continue smoothly on its course.
* <p>The main class of a midlet extends javax.microedition.midlet.MIDlet.</p>
* <p>The screen displays are created and managed by subclasses of the
* abstract base class Displayable such as List. A Displayable object 
* may have commands and listeners associated with it.</p>
* <p>Commands are mapped to various buttons on the device.  This mapping
* is controlled by the Application Management Software in the device.
* The action taken in response to a command is controlled by the midlet
* with one or more classes that implement the CommandListener interface.</p>
* <p>$Id: Hello.java,v 1.3 2003/04/01 06:01:26 finson Exp $</p>
*/
public class Hello extends MIDlet implements CommandListener {
	/**
	* Create a new midlet based on the Hello class.  Note that this
	* constructor is called only once when the midlet is launched, and
	* it should perform basic initialization.  However, the midlet is
	* not actually running and in control of the display until the 
	* life cycle method startApp() is called.
	* <p>In this simple HelloWorld midlet, we just create a Displayable
	* screen object of type List, add our text to it, add a Command and a 
	* CommandListener, and then return.
	*/
	public Hello() {
		aScreen = new List("Simple Hello",List.IMPLICIT);
		aScreen.append("Hello World",null);
		exitCommand = new Command("Exit",Command.EXIT,1);
		aScreen.addCommand(exitCommand);
		aScreen.setCommandListener(this);
	}
	/**
	* Signals the MIDlet that it has entered the Active state.
	* In the Active state the MIDlet may hold resources. The Display
	* is known to be ready for dedicated use at this point, so
	* we get a reference to it and tell it to display the screen
	* that we created earlier in the constructor.
	*/
	protected void startApp() {
		Display d = Display.getDisplay(this);
		d.setCurrent(aScreen);
	}
	/**
	* Indicates that Command c has occurred on Displayable d.
	* The user has selected one of the Commands that we made
	* available for the currently displayed Displayable, so
	* as a CommandListener, we are responsible for taking the
	* appropriate action.  Note that the system is essentially
	* blocked while this method is executing, so this method
	* should return very quickly.  Long running tasks should be
	* delegated to another thread.
	* @param c a Command object identifying the command. This is either
	* one of the application's Commands that have been added to 
	* the Displayable with Displayable.addCommand(Command) or is
	* the implicit SELECT_COMMAND of List.
	* @param d the Displayable on which this event has occurred
	*/
	public void commandAction(Command c,Displayable d) {
		if (c == exitCommand) {
			destroyApp(true);
			notifyDestroyed();
		}
	}
	/**
	* Signals the MIDlet to stop and enter the Paused state.
	* In the Paused state the MIDlet must release shared resources
	* and become quiescent. This method will only be called called
	* when the MIDlet is in the Active state.
	*/
	protected void pauseApp() {
	}
	/**
	* Signals the MIDlet to terminate and enter the Destroyed state.
	* In the destroyed state the MIDlet must release all resources
	* and save any persistent state. This method may be called by the
	* Application Management Software while the midlet is in the Paused
	* or Active states.  If the method is called from within the midlet
	* itself, then the midlet should also call notifyDestroyed to let
	* the AMS know that we are history.
	* @param unconditional If true when this method is called, the MIDlet
	* must cleanup and release all resources. If false the MIDlet may 
	* throw MIDletStateChangeException to indicate it does not want to
	* be destroyed at this time.  Our simple example does not implement
	* this optional behavior.
	*/
	protected void destroyApp(boolean unconditional) {
	}
	
	//-----------------------------------------------------------------------
	
	/** The Displayable that is used to show the HelloWorld message. */
	private List aScreen;
	/** The Command object that we use to let the user exit this midlet. */
	private Command exitCommand;
}
